# Aloha Python Package

### How to test my package locally?

```bash
# Step 1: install the testable whl file first
pip install dist/alohapy-0.1-py3-none-any.whl
# Step 2: run test.py file for testing my package
python test.py
```

### Just for some recall purpose

```bash
python setup.py sdist bdist_wheel # build package locally
```
